@@ -25,9 +25,10 @@
 #include <QByteArray>
 #include <QDataStream>
 #include <QDateTime>
+#include <QIODevice>
 #include <QList>
 
-#include <assert.h>
+#include <cassert>
 
 using namespace KTnef;
 
